@@ -1,7 +1,6 @@
 import argparse
-from matplotlib.pyplot import show
 
-from . import plot_all, grid, precip
+from . import plot_all, grid, Efield, precip
 
 
 def cli():
@@ -11,13 +10,15 @@ def cli():
     p.add_argument(
         "which",
         help="which plots to make",
-        choices=["all", "grid", "precip"],
-        nargs="?",
+        choices=["all", "grid", "Efield", "precip"],
+        nargs="+",
         default="all",
     )
     p.add_argument("--mayavi", help="do 3D Mayavi plots", action="store_true")
     p.add_argument("-var", help="plot these variables", nargs="+")
-    p.add_argument("-save", help="save plot format", default="png")
+    p.add_argument(
+        "-save", help="save plot format", choices=["png", "svg", "eps", "pdf"], default="png"
+    )
     p = p.parse_args()
 
     if p.mayavi:
@@ -26,15 +27,15 @@ def cli():
         plot_3d(p.direc, p.var, saveplot_fmt=p.save)
         return
 
-    if p.which == "all":
+    if "all" in p.which:
         plot_all(p.direc, p.var, saveplot_fmt=p.save)
-    elif p.which == "grid":
+    if "grid" in p.which:
         grid(p.direc)
-    elif p.which == "precip":
+    if "Efield" in p.which:
+        Efield(p.direc)
+    if "precip" in p.which:
         precip(p.direc)
 
-    show()
-
 
 if __name__ == "__main__":
     cli()
