@@ -7,7 +7,7 @@ import shutil
 import os
 
 import gemini3d.prereqs as gcp
-import gemini3d.build as gb
+import gemini3d.cmake as cmake
 
 
 @pytest.mark.skipif(shutil.which("gfortran") is None, reason="test assumes GCC")
@@ -25,12 +25,12 @@ def test_find_intel():
 @pytest.mark.parametrize("name", ["MPI COMPONENTS C Fortran", "LAPACK"])
 def test_find_cmake(name):
 
-    assert gb.cmake_find_library(name, [], None), f"{name} not found"
+    assert cmake.find_library(name, [], None), f"{name} not found"
 
 
 def test_cmake_notfound():
 
-    assert not gb.cmake_find_library("abc123zxyb", [], None), "should not be found"
+    assert not cmake.find_library("abc123zxyb", [], None), "should not be found"
 
 
 @pytest.mark.parametrize("name", ["lapack", "scalapack"])
